@@ -10,9 +10,10 @@ def generate_target_stub(functionDefinitionDict, targetFile=None):
     lines = []
     
     
-    for funcName, prmList in functionDefinitionDict.items():
+    for funcName, funcDict in functionDefinitionDict.items():
         inPmrs = []
         outPrms = []
+        prmList = funcDict["parameters"]
         for prmNm, inOut, typeString in prmList:
             if inOut == "in":
                 inPmrs.append((prmNm, typeString))
@@ -22,16 +23,17 @@ def generate_target_stub(functionDefinitionDict, targetFile=None):
                 raise RuntimeError(f"Unexpected inOut value '{inOut}'")
             
         lines.append("# Input prms: "+", ".join([f"{nm} {t}" for nm, t in inPmrs]))
+        lines.append("# Return: {}".format(funcDict["return"]))
         lines.append(f"def {funcName}({', '.join([nm for nm, t in inPmrs])}):")
         lines.append("    # Output prms: "+", ".join([f"{nm} {t}" for nm, t in outPrms]))
-        lines.append("    return {{{}}}".format(", ".join([f'"{nm}" : None' for nm, t in outPrms])))
+        lines.append("    return {{{}}}, 0".format(", ".join([f'"{nm}" : None' for nm, t in outPrms])))
         lines.append("")
         
-        if targetFile:
-            with open(targetFile, 'w') as fh:
-                for l in lines:
-                    fh.write(l+"\n")
-        else:
+    if targetFile:
+        with open(targetFile, 'w') as fh:
             for l in lines:
-                print(l)
+                fh.write(l+"\n")
+    else:
+        for l in lines:
+            print(l)
     
\ No newline at end of file
